@@ -13,12 +13,14 @@
 package devworkspaceconfig
 
 import (
+	"encoding/json"
 	"fmt"
 
 	controllerv1alpha1 "github.com/devfile/devworkspace-operator/apis/controller/v1alpha1"
 	chev2 "github.com/eclipse-che/che-operator/api/v2"
 	"github.com/eclipse-che/che-operator/pkg/common/chetypes"
 	"github.com/eclipse-che/che-operator/pkg/common/constants"
+	defaults "github.com/eclipse-che/che-operator/pkg/common/operator-defaults"
 	"github.com/eclipse-che/che-operator/pkg/common/utils"
 	"github.com/eclipse-che/che-operator/pkg/deploy"
 	v1 "k8s.io/api/apps/v1"
@@ -88,25 +90,43 @@ func updateWorkspaceConfig(cheCluster *chev2.CheCluster, operatorConfig *control
 
 	updateWorkspaceServiceAccountConfig(devEnvironments, operatorConfig.Workspace)
 
-	if err := updateWorkspacePodSchedulerNameConfig(devEnvironments, operatorConfig.Workspace); err != nil {
-		return err
-	}
+	updateWorkspacePodSchedulerNameConfig(devEnvironments, operatorConfig.Workspace)
 
 	updateProjectCloneConfig(devEnvironments, operatorConfig.Workspace)
 
-	operatorConfig.Workspace.ContainerSecurityContext = nil
-	if cheCluster.IsContainerBuildCapabilitiesEnabled() {
-		operatorConfig.Workspace.ContainerSecurityContext = constants.DefaultWorkspaceContainerSecurityContext.DeepCopy()
+	if err := updateSecurityContext(operatorConfig, cheCluster); err != nil {
+		return err
 	}
 
 	updateStartTimeout(operatorConfig, devEnvironments.StartTimeoutSeconds)
 
 	updatePersistUserHomeConfig(devEnvironments.PersistUserHome, operatorConfig.Workspace)
 
+	updateWorkspaceImagePullPolicy(devEnvironments.ImagePullPolicy, operatorConfig.Workspace)
+
 	operatorConfig.Workspace.DeploymentStrategy = v1.DeploymentStrategyType(utils.GetValue(string(devEnvironments.DeploymentStrategy), constants.DefaultDeploymentStrategy))
 	return nil
 }
 
+func updateSecurityContext(operatorConfig *controllerv1alpha1.OperatorConfiguration, cheCluster *chev2.CheCluster) error {
+	operatorConfig.Workspace.ContainerSecurityContext = nil
+	if cheCluster.IsContainerBuildCapabilitiesEnabled() {
+		defaultContainerSecurityContext, err := getDefaultContainerSecurityContext()
+		if err != nil {
+			return err
+		}
+		operatorConfig.Workspace.ContainerSecurityContext = defaultContainerSecurityContext
+	} else if cheCluster.Spec.DevEnvironments.Security.ContainerSecurityContext != nil {
+		operatorConfig.Workspace.ContainerSecurityContext = cheCluster.Spec.DevEnvironments.Security.ContainerSecurityContext
+	}
+
+	operatorConfig.Workspace.PodSecurityContext = nil
+	if cheCluster.Spec.DevEnvironments.Security.PodSecurityContext != nil {
+		operatorConfig.Workspace.PodSecurityContext = cheCluster.Spec.DevEnvironments.Security.PodSecurityContext
+	}
+	return nil
+}
+
 func updateStartTimeout(operatorConfig *controllerv1alpha1.OperatorConfiguration, startTimeoutSeconds *int32) {
 	if startTimeoutSeconds == nil {
 		// Allow the default start timeout of 5 minutes to be used if devEnvironments.StartTimeoutSeconds is unset
@@ -158,6 +178,10 @@ func updatePersistUserHomeConfig(persistentHomeConfig *chev2.PersistentHomeConfi
 	}
 }
 
+func updateWorkspaceImagePullPolicy(imagePullPolicy corev1.PullPolicy, workspaceConfig *controllerv1alpha1.WorkspaceConfig) {
+	workspaceConfig.ImagePullPolicy = string(imagePullPolicy)
+}
+
 func updateWorkspaceServiceAccountConfig(devEnvironments *chev2.CheClusterDevEnvironments, workspaceConfig *controllerv1alpha1.WorkspaceConfig) {
 	isNamespaceAutoProvisioned := pointer.BoolDeref(devEnvironments.DefaultNamespace.AutoProvision, constants.DefaultAutoProvision)
 
@@ -169,9 +193,8 @@ func updateWorkspaceServiceAccountConfig(devEnvironments *chev2.CheClusterDevEnv
 	}
 }
 
-func updateWorkspacePodSchedulerNameConfig(devEnvironments *chev2.CheClusterDevEnvironments, workspaceConfig *controllerv1alpha1.WorkspaceConfig) error {
+func updateWorkspacePodSchedulerNameConfig(devEnvironments *chev2.CheClusterDevEnvironments, workspaceConfig *controllerv1alpha1.WorkspaceConfig) {
 	workspaceConfig.SchedulerName = devEnvironments.PodSchedulerName
-	return nil
 }
 
 func updateProjectCloneConfig(devEnvironments *chev2.CheClusterDevEnvironments, workspaceConfig *controllerv1alpha1.WorkspaceConfig) {
@@ -190,6 +213,17 @@ func updateProjectCloneConfig(devEnvironments *chev2.CheClusterDevEnvironments,
 	workspaceConfig.ProjectCloneConfig.Resources = cheResourcesToCoreV1Resources(container.Resources)
 }
 
+// Returns the default container security context required for container builds.
+// Returns an error if the default container security context could not be retrieved.
+func getDefaultContainerSecurityContext() (*corev1.SecurityContext, error) {
+	containerSecurityContext := &corev1.SecurityContext{}
+	err := json.Unmarshal([]byte(defaults.GetDevEnvironmentsContainerSecurityContext()), &containerSecurityContext)
+	if err != nil {
+		return nil, err
+	}
+	return containerSecurityContext, nil
+}
+
 // cheResourcesToCoreV1Resources converts a Che resources struct to the usual Kubernetes object by directly copying fields.
 // It does not set any default values or include logic for removing requests/limits that are set to "0" as it is intended
 // to prepare resources for the DevWorkspace Operator, which has its own defaults and handling of "0" values.
